==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/TextView.h <==
#if !defined(AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_)
#define AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// TextView.h : wb_[ t@C
//
#include "MimeDecode.h"
#include "BitmapRichEditView.h"

/////////////////////////////////////////////////////////////////////////////
// CTextView r[

class CTextView : public CBitmapRichEditView
{
protected:
	CTextView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CTextView)

// Agr[g
public:
	int m_current_part;			// [}`p[g̏ꍇAݕ\Ăp[g̔ԍB}`p[głȂꍇ́A0
	CString m_mail;				// [Ŝi[
	CString m_body;				// [̖{i[
	CString m_header;			// wb_i[
	CString m_text;				// ݕ\Ăei[
	CString m_path;				// [i[t@C̃tpX
	CString m_display_header;	// TextViewɕ\Ƃ̖{ɂ镔
	long m_onlink;				// OnLinkdɌĂ΂̋̑΍iƂ낪NbNꂽXj
	CFont m_font;				// tHgi[

// Iy[V
public:
	void Clear();
	CFont *GetFontEx();
	void ReDisplay();
	void SetFontColorAndLink();
	void SetFontEx(LOGFONT &lf);
	CMimeDecode m_md;
	CString m_multipart_header;
  	void Update(CString path);
	void Update2(CString mail);
	void Font();
	CString GetCurrentPath();
	CString GetCurrentText();
	CString GetCurrentRawHeader();
	CString GetCurrentHeader();
	CString GetCurrentSubject();
	CString GetCurrentFrom();
	CString GetCurrentTo();
	CString GetCurrentCc();
	CString GetCurrentDate();
	CString GetCurrentMsgID();
	CString GetCurrentBody();
	CString GetCurrentReplyTo();
	CString GetCurrentCT();
	int GetCurrentCTE();
	void DisplayPart(int part);
	BOOL IsPgpMime();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CTextView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CTextView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:
	//{{AFX_MSG(CTextView)
	afx_msg void OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnPopupCopy();
	afx_msg void OnPopupSelall();
	afx_msg void OnPopupBrowser();
	afx_msg void OnPopupEditor();
	afx_msg void OnSetFocus(CWnd* pOldWnd);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	CString m_header_template;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_)

==> pochy-0.2-src.tar.gz: pochy-0.2-src/TextView.h <==
#if !defined(AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_)
#define AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// TextView.h : wb_[ t@C
//
#include "MimeDecode.h"
#include "BitmapRichEditView.h"

/////////////////////////////////////////////////////////////////////////////
// CTextView r[

class CTextView : public CBitmapRichEditView
{
protected:
	CTextView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CTextView)

// Agr[g
public:
	int m_current_part;			// [}`p[g̏ꍇAݕ\Ăp[g̔ԍB}`p[głȂꍇ́A0
	CString m_mail;				// [Ŝi[
	CString m_body;				// [̖{i[
	CString m_header;			// wb_i[
	CString m_text;				// ݕ\Ăei[
	CString m_path;				// [i[t@C̃tpX
	CString m_display_header;	// TextViewɕ\Ƃ̖{ɂ镔
	long m_onlink;				// OnLinkdɌĂ΂̋̑΍iƂ낪NbNꂽXj
	CFont m_font;				// tHgi[

// Iy[V
public:
	void Clear();
	CFont *GetFontEx();
	void ReDisplay();
	void SetFontColorAndLink();
	void SetFontEx(LOGFONT &lf);
	CMimeDecode m_md;
	CString m_multipart_header;
  	void Update(CString path);
	void Update2(CString mail);
	void Font();
	CString GetCurrentPath();
	CString GetCurrentText();
	CString GetCurrentRawHeader();
	CString GetCurrentHeader();
	CString GetCurrentSubject();
	CString GetCurrentFrom();
	CString GetCurrentTo();
	CString GetCurrentCc();
	CString GetCurrentDate();
	CString GetCurrentMsgID();
	CString GetCurrentBody();
	CString GetCurrentReplyTo();
	CString GetCurrentCT();
	int GetCurrentCTE();
	void DisplayPart(int part);
	BOOL IsPgpMime();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CTextView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CTextView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:
	//{{AFX_MSG(CTextView)
	afx_msg BOOL OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult);
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnPopupCopy();
	afx_msg void OnPopupSelall();
	afx_msg void OnPopupBrowser();
	afx_msg void OnPopupEditor();
	afx_msg void OnSetFocus(CWnd* pOldWnd);
	afx_msg void OnPageUp();
	afx_msg bool OnPageDown();
	afx_msg void OnScrollAndNextUnread();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	int GetLastVisibleLine();
	CString m_header_template;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOTEXTVIEW_H__38490840_510E_11D5_B88F_00402676496C__INCLUDED_)
